//#define XERR
#include "mammotomo.ih"

MammoTomo::MammoTomo(char const *sID, uint16_t lineNr, ConfigSrc src, 
                     string const &id, istream &in)
:
    ModBase(id)
{
    uint16_t cost;
    in >> cost;

    for (size_t idx = 0; idx != N_DOSES; ++idx)     // read doses
        in >> d_dose[idx];

    for (size_t idx = 0; idx != N_SENS; ++idx)      // read sensitivities
        in >> d_sens[idx];

    readSpecifications(sID, lineNr, src, id, in);

    setCost(cost);
}
